@@ -13,7 +13,6 @@
 #include <cstring>
 
 // Qt
-#include <QX11Info>
 #include <QCoreApplication>
 #include <QGuiApplication>
 #include <QScreen>
@@ -40,11 +39,12 @@
 
 #include <pipewire/pipewire.h>
 
-#include <limits.h>
+#include <climits>
 
 #include "pw_framebuffer.h"
 #include "xdp_dbus_screencast_interface.h"
 #include "xdp_dbus_remotedesktop_interface.h"
+#include "krfb_fb_pipewire_debug.h"
 
 static const uint MIN_SUPPORTED_XDP_KDE_SC_VERSION = 1;
 
@@ -176,10 +176,10 @@ private:
     struct {
         quint32 width;
         quint32 height;
-    } screenGeometry;
+    } screenGeometry = {};
 
     // Allowed devices
-    uint devices;
+    uint devices = 0;
 
     // sanity indicator
     bool isValid = true;
@@ -215,15 +215,15 @@ PWFrameBuffer::Private::Private(PWFrameBuffer *q) : q(q)
 void PWFrameBuffer::Private::initDbus()
 {
     qInfo() << "Initializing D-Bus connectivity with XDG Desktop Portal";
-    dbusXdpScreenCastService.reset(new OrgFreedesktopPortalScreenCastInterface(QLatin1String("org.freedesktop.portal.Desktop"),
-                                                                     QLatin1String("/org/freedesktop/portal/desktop"),
+    dbusXdpScreenCastService.reset(new OrgFreedesktopPortalScreenCastInterface(QStringLiteral("org.freedesktop.portal.Desktop"),
+                                                                     QStringLiteral("/org/freedesktop/portal/desktop"),
                                                                      QDBusConnection::sessionBus()));
-    dbusXdpRemoteDesktopService.reset(new OrgFreedesktopPortalRemoteDesktopInterface(QLatin1String("org.freedesktop.portal.Desktop"),
-                                                                     QLatin1String("/org/freedesktop/portal/desktop"),
+    dbusXdpRemoteDesktopService.reset(new OrgFreedesktopPortalRemoteDesktopInterface(QStringLiteral("org.freedesktop.portal.Desktop"),
+                                                                     QStringLiteral("/org/freedesktop/portal/desktop"),
                                                                      QDBusConnection::sessionBus()));
     auto version = dbusXdpScreenCastService->version();
     if (version < MIN_SUPPORTED_XDP_KDE_SC_VERSION) {
-        qWarning() << "Unsupported XDG Portal screencast interface version:" << version;
+        qCWarning(KRFB_FB_PIPEWIRE) << "Unsupported XDG Portal screencast interface version:" << version;
         isValid = false;
         return;
     }
@@ -231,11 +231,11 @@ void PWFrameBuffer::Private::initDbus()
     // create session
     auto sessionParameters = QVariantMap {
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
-        { QLatin1String("session_handle_token"), QStringLiteral("krfb%1").arg(QRandomGenerator::global()->generate()) },
-        { QLatin1String("handle_token"), QStringLiteral("krfb%1").arg(QRandomGenerator::global()->generate()) }
+        { QStringLiteral("session_handle_token"), QStringLiteral("krfb%1").arg(QRandomGenerator::global()->generate()) },
+        { QStringLiteral("handle_token"), QStringLiteral("krfb%1").arg(QRandomGenerator::global()->generate()) }
 #else
-        { QLatin1String("session_handle_token"), QStringLiteral("krfb%1").arg(qrand()) },
-        { QLatin1String("handle_token"), QStringLiteral("krfb%1").arg(qrand()) }
+        { QStringLiteral("session_handle_token"), QStringLiteral("krfb%1").arg(qrand()) },
+        { QStringLiteral("handle_token"), QStringLiteral("krfb%1").arg(qrand()) }
 #endif
     };
     auto sessionReply = dbusXdpRemoteDesktopService->CreateSession(sessionParameters);
@@ -249,8 +249,8 @@ void PWFrameBuffer::Private::initDbus()
     qInfo() << "DBus session created: " << sessionReply.value().path();
     QDBusConnection::sessionBus().connect(QString(),
                                           sessionReply.value().path(),
-                                          QLatin1String("org.freedesktop.portal.Request"),
-                                          QLatin1String("Response"),
+                                          QStringLiteral("org.freedesktop.portal.Request"),
+                                          QStringLiteral("Response"),
                                           this->q,
                                           SLOT(handleXdpSessionCreated(uint, QVariantMap)));
 }
@@ -270,34 +270,34 @@ void PWFrameBuffer::handleXdpSessionCreated(quint32 code, QVariantMap results)
 void PWFrameBuffer::Private::handleSessionCreated(quint32 &code, QVariantMap &results)
 {
     if (code != 0) {
-        qWarning() << "Failed to create session: " << code;
+        qCWarning(KRFB_FB_PIPEWIRE) << "Failed to create session: " << code;
         isValid = false;
         return;
     }
 
-    sessionPath = QDBusObjectPath(results.value(QLatin1String("session_handle")).toString());
+    sessionPath = QDBusObjectPath(results.value(QStringLiteral("session_handle")).toString());
 
     // select sources for the session
     auto selectionOptions = QVariantMap {
         // We have to specify it's an uint, otherwise xdg-desktop-portal will not forward it to backend implementation
-        { QLatin1String("types"), QVariant::fromValue<uint>(7) }, // request all (KeyBoard, Pointer, TouchScreen)
+        { QStringLiteral("types"), QVariant::fromValue<uint>(7) }, // request all (KeyBoard, Pointer, TouchScreen)
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
-        { QLatin1String("handle_token"), QStringLiteral("krfb%1").arg(QRandomGenerator::global()->generate()) }
+        { QStringLiteral("handle_token"), QStringLiteral("krfb%1").arg(QRandomGenerator::global()->generate()) }
 #else
-        { QLatin1String("handle_token"), QStringLiteral("krfb%1").arg(qrand()) }
+        { QStringLiteral("handle_token"), QStringLiteral("krfb%1").arg(qrand()) }
 #endif
     };
     auto selectorReply = dbusXdpRemoteDesktopService->SelectDevices(sessionPath, selectionOptions);
     selectorReply.waitForFinished();
     if (!selectorReply.isValid()) {
-        qWarning() << "Couldn't select devices for the remote-desktop session";
+        qCWarning(KRFB_FB_PIPEWIRE) << "Couldn't select devices for the remote-desktop session";
         isValid = false;
         return;
     }
     QDBusConnection::sessionBus().connect(QString(),
                                           selectorReply.value().path(),
-                                          QLatin1String("org.freedesktop.portal.Request"),
-                                          QLatin1String("Response"),
+                                          QStringLiteral("org.freedesktop.portal.Request"),
+                                          QStringLiteral("Response"),
                                           this->q,
                                           SLOT(handleXdpDevicesSelected(uint, QVariantMap)));
 }
@@ -317,32 +317,32 @@ void PWFrameBuffer::Private::handleDevicesSelected(quint32 &code, QVariantMap &r
 {
     Q_UNUSED(results)
     if (code != 0) {
-        qWarning() << "Failed to select devices: " << code;
+        qCWarning(KRFB_FB_PIPEWIRE) << "Failed to select devices: " << code;
         isValid = false;
         return;
     }
 
     // select sources for the session
     auto selectionOptions = QVariantMap {
-        { QLatin1String("types"), QVariant::fromValue<uint>(1) }, // only MONITOR is supported
-        { QLatin1String("multiple"), false },
+        { QStringLiteral("types"), QVariant::fromValue<uint>(1) }, // only MONITOR is supported
+        { QStringLiteral("multiple"), false },
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
-        { QLatin1String("handle_token"), QStringLiteral("krfb%1").arg(QRandomGenerator::global()->generate()) }
+        { QStringLiteral("handle_token"), QStringLiteral("krfb%1").arg(QRandomGenerator::global()->generate()) }
 #else
-        { QLatin1String("handle_token"), QStringLiteral("krfb%1").arg(qrand()) }
+        { QStringLiteral("handle_token"), QStringLiteral("krfb%1").arg(qrand()) }
 #endif
     };
     auto selectorReply = dbusXdpScreenCastService->SelectSources(sessionPath, selectionOptions);
     selectorReply.waitForFinished();
     if (!selectorReply.isValid()) {
-        qWarning() << "Couldn't select sources for the screen-casting session";
+        qCWarning(KRFB_FB_PIPEWIRE) << "Couldn't select sources for the screen-casting session";
         isValid = false;
         return;
     }
     QDBusConnection::sessionBus().connect(QString(),
                                           selectorReply.value().path(),
-                                          QLatin1String("org.freedesktop.portal.Request"),
-                                          QLatin1String("Response"),
+                                          QStringLiteral("org.freedesktop.portal.Request"),
+                                          QStringLiteral("Response"),
                                           this->q,
                                           SLOT(handleXdpSourcesSelected(uint, QVariantMap)));
 }
@@ -363,7 +363,7 @@ void PWFrameBuffer::handleXdpSourcesSelected(quint32 code, QVariantMap results)
 void PWFrameBuffer::Private::handleSourcesSelected(quint32 &code, QVariantMap &)
 {
     if (code != 0) {
-        qWarning() << "Failed to select sources: " << code;
+        qCWarning(KRFB_FB_PIPEWIRE) << "Failed to select sources: " << code;
         isValid = false;
         return;
     }
@@ -371,17 +371,17 @@ void PWFrameBuffer::Private::handleSourcesSelected(quint32 &code, QVariantMap &)
     // start session
     auto startParameters = QVariantMap {
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
-        { QLatin1String("handle_token"), QStringLiteral("krfb%1").arg(QRandomGenerator::global()->generate()) }
+        { QStringLiteral("handle_token"), QStringLiteral("krfb%1").arg(QRandomGenerator::global()->generate()) }
 #else
-        { QLatin1String("handle_token"), QStringLiteral("krfb%1").arg(qrand()) }
+        { QStringLiteral("handle_token"), QStringLiteral("krfb%1").arg(qrand()) }
 #endif
     };
     auto startReply = dbusXdpRemoteDesktopService->Start(sessionPath, QString(), startParameters);
     startReply.waitForFinished();
     QDBusConnection::sessionBus().connect(QString(),
                                           startReply.value().path(),
-                                          QLatin1String("org.freedesktop.portal.Request"),
-                                          QLatin1String("Response"),
+                                          QStringLiteral("org.freedesktop.portal.Request"),
+                                          QStringLiteral("Response"),
                                           this->q,
                                           SLOT(handleXdpRemoteDesktopStarted(uint, QVariantMap)));
 }
@@ -402,16 +402,16 @@ void PWFrameBuffer::handleXdpRemoteDesktopStarted(quint32 code, QVariantMap resu
 void PWFrameBuffer::Private::handleRemoteDesktopStarted(quint32 &code, QVariantMap &results)
 {
     if (code != 0) {
-        qWarning() << "Failed to start screencast: " << code;
+        qCWarning(KRFB_FB_PIPEWIRE) << "Failed to start screencast: " << code;
         isValid = false;
         return;
     }
 
     // there should be only one stream
-    Streams streams = qdbus_cast<Streams>(results.value(QLatin1String("streams")));
+    Streams streams = qdbus_cast<Streams>(results.value(QStringLiteral("streams")));
     if (streams.isEmpty()) {
         // maybe we should check deeper with qdbus_cast but this suffices for now
-        qWarning() << "Failed to get screencast streams";
+        qCWarning(KRFB_FB_PIPEWIRE) << "Failed to get screencast streams";
         isValid = false;
         return;
     }
@@ -419,23 +419,23 @@ void PWFrameBuffer::Private::handleRemoteDesktopStarted(quint32 &code, QVariantM
     auto streamReply = dbusXdpScreenCastService->OpenPipeWireRemote(sessionPath, QVariantMap());
     streamReply.waitForFinished();
     if (!streamReply.isValid()) {
-        qWarning() << "Couldn't open pipewire remote for the screen-casting session";
+        qCWarning(KRFB_FB_PIPEWIRE) << "Couldn't open pipewire remote for the screen-casting session";
         isValid = false;
         return;
     }
 
     pipewireFd = streamReply.value();
     if (!pipewireFd.isValid()) {
-        qWarning() << "Couldn't get pipewire connection file descriptor";
+        qCWarning(KRFB_FB_PIPEWIRE) << "Couldn't get pipewire connection file descriptor";
         isValid = false;
         return;
     }
 
-    QSize streamResolution = qdbus_cast<QSize>(streams.first().map.value(QLatin1String("size")));
+    QSize streamResolution = qdbus_cast<QSize>(streams.first().map.value(QStringLiteral("size")));
     screenGeometry.width = streamResolution.width();
     screenGeometry.height = streamResolution.height();
 
-    devices = results.value(QLatin1String("types")).toUInt();
+    devices = results.value(QStringLiteral("types")).toUInt();
 
     pwStreamNodeId = streams.first().nodeId;
 
@@ -443,7 +443,7 @@ void PWFrameBuffer::Private::handleRemoteDesktopStarted(quint32 &code, QVariantM
     q->fb = static_cast<char*>(malloc(screenGeometry.width * screenGeometry.height * 4));
 
     if (!q->fb) {
-        qWarning() << "Failed to allocate buffer";
+        qCWarning(KRFB_FB_PIPEWIRE) << "Failed to allocate buffer";
         isValid = false;
         return;
     }
@@ -467,13 +467,13 @@ void PWFrameBuffer::Private::initPw() {
     pwMainLoop = pw_thread_loop_new("pipewire-main-loop", nullptr);
     pwContext = pw_context_new(pw_thread_loop_get_loop(pwMainLoop), nullptr, 0);
     if (!pwContext) {
-        qWarning() << "Failed to create PipeWire context";
+        qCWarning(KRFB_FB_PIPEWIRE) << "Failed to create PipeWire context";
         return;
     }
 
     pwCore = pw_context_connect(pwContext, nullptr, 0);
     if (!pwCore) {
-        qWarning() << "Failed to connect PipeWire context";
+        qCWarning(KRFB_FB_PIPEWIRE) << "Failed to connect PipeWire context";
         return;
     }
 
@@ -481,7 +481,7 @@ void PWFrameBuffer::Private::initPw() {
 
     pwStream = createReceivingStream();
     if (!pwStream) {
-        qWarning() << "Failed to create PipeWire stream";
+        qCWarning(KRFB_FB_PIPEWIRE) << "Failed to create PipeWire stream";
         return;
     }
 #else
@@ -502,12 +502,12 @@ void PWFrameBuffer::Private::initPw() {
 #endif
 
     if (pw_thread_loop_start(pwMainLoop) < 0) {
-        qWarning() << "Failed to start main PipeWire loop";
+        qCWarning(KRFB_FB_PIPEWIRE) << "Failed to start main PipeWire loop";
         isValid = false;
     }
 }
 
-#if !PW_CHECK_VERSION(0, 2, 9)
+#if !PW_CHECK_VERSION(0, 2, 90)
 /**
  * @brief PWFrameBuffer::Private::initializePwTypes - helper method to initialize and map all needed
  *        Pipewire types from core to type structure.
@@ -547,11 +547,11 @@ void PWFrameBuffer::Private::onStateChanged(void *data, pw_remote_state /*old*/,
 {
     qInfo() << "remote state: " << pw_remote_state_as_string(state);
 
-    PWFrameBuffer::Private *d = static_cast<PWFrameBuffer::Private*>(data);
+    auto d = static_cast<PWFrameBuffer::Private*>(data);
 
     switch (state) {
     case PW_REMOTE_STATE_ERROR:
-        qWarning() << "remote error: " << error;
+        qCWarning(KRFB_FB_PIPEWIRE) << "remote error: " << error;
         break;
     case PW_REMOTE_STATE_CONNECTED:
         d->pwStream = d->createReceivingStream();
@@ -578,7 +578,7 @@ void PWFrameBuffer::Private::onStreamStateChanged(void *data, pw_stream_state /*
 #if PW_CHECK_VERSION(0, 2, 90)
     switch (state) {
     case PW_STREAM_STATE_ERROR:
-        qWarning() << "pipewire stream error: " << error_message;
+        qCWarning(KRFB_FB_PIPEWIRE) << "pipewire stream error: " << error_message;
         break;
     case PW_STREAM_STATE_PAUSED:
             pw_stream_set_active(d->pwStream, true);
@@ -591,7 +591,7 @@ void PWFrameBuffer::Private::onStreamStateChanged(void *data, pw_stream_state /*
 #else
     switch (state) {
     case PW_STREAM_STATE_ERROR:
-        qWarning() << "pipewire stream error: " << error_message;
+        qCWarning(KRFB_FB_PIPEWIRE) << "pipewire stream error: " << error_message;
         break;
     case PW_STREAM_STATE_CONFIGURE:
         pw_stream_set_active(d->pwStream, true);
@@ -704,7 +704,7 @@ static void syncDmaBuf(int fd, uint64_t start_or_end)
         if (ret == -1 && errno == EINTR) {
             continue;
         } else if (ret == -1) {
-            qWarning() << "Failed to synchronize DMA buffer: " << strerror(errno);
+            qCWarning(KRFB_FB_PIPEWIRE) << "Failed to synchronize DMA buffer: " << strerror(errno);
             break;
         } else {
             break;
@@ -717,14 +717,10 @@ void PWFrameBuffer::Private::handleFrame(pw_buffer *pwBuffer)
 {
     auto *spaBuffer = pwBuffer->buffer;
     void *src = spaBuffer->datas[0].data;
-    if (!src) {
-        qDebug() << "discarding null buffer";
-        return;
-    }
 
 #if PW_CHECK_VERSION(0, 2, 90)
-    if (spaBuffer->datas->type != SPA_DATA_DmaBuf) {
-        qDebug() << "discarding null buffer";
+    if (!src && spaBuffer->datas->type != SPA_DATA_DmaBuf) {
+        qCDebug(KRFB_FB_PIPEWIRE)  << "discarding null buffer";
         return;
     }
 #endif
@@ -740,7 +736,7 @@ void PWFrameBuffer::Private::handleFrame(pw_buffer *pwBuffer)
             nullptr, spaBuffer->datas[0].maxsize + spaBuffer->datas[0].mapoffset,
             PROT_READ, MAP_PRIVATE, fd, 0);
         if (map == MAP_FAILED) {
-            qWarning() << "Failed to mmap the dmabuf: " << strerror(errno);
+            qCWarning(KRFB_FB_PIPEWIRE) << "Failed to mmap the dmabuf: " << strerror(errno);
             return;
         }
 
@@ -759,7 +755,7 @@ void PWFrameBuffer::Private::handleFrame(pw_buffer *pwBuffer)
             PROT_READ, MAP_PRIVATE, spaBuffer->datas->fd, 0));
 
         if (map == MAP_FAILED) {
-            qWarning() << "Failed to mmap the memory: " << strerror(errno);
+            qCWarning(KRFB_FB_PIPEWIRE) << "Failed to mmap the memory: " << strerror(errno);
             return;
         }
         src = SPA_MEMBER(map, spaBuffer->datas[0].mapoffset, uint8_t);
@@ -772,7 +768,7 @@ void PWFrameBuffer::Private::handleFrame(pw_buffer *pwBuffer)
 
     const qint32 srcStride = spaBuffer->datas[0].chunk->stride;
     if (srcStride != q->paddedWidth()) {
-        qWarning() << "Got buffer with stride different from screen stride" << srcStride << "!=" << q->paddedWidth();
+        qCWarning(KRFB_FB_PIPEWIRE) << "Got buffer with stride different from screen stride" << srcStride << "!=" << q->paddedWidth();
         return;
     }
 
@@ -851,7 +847,7 @@ pw_stream *PWFrameBuffer::Private::createReceivingStream()
 #else
     if (pw_stream_connect(stream, PW_DIRECTION_INPUT, nullptr, flags, params, 1) != 0) {
 #endif
-        qWarning() << "Could not connect receiving stream";
+        qCWarning(KRFB_FB_PIPEWIRE) << "Could not connect receiving stream";
         isValid = false;
     }
 
